<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fa_IR">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>انتخاب یک یا چند دستگاه </translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>دوربین</translation>
    </message>
</context>
<context>
    <name>QvkCameraSettingsDialog</name>
    <message>
        <source>Camera settings</source>
        <translation>تنظیمات دوربین</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>حذف فریم دور پنچره</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>عمودی چرخاندن</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>افقی چرخاندن</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>معکوس کردن</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>خاکستری</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>سیاه و سفید</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>تغییر به حالت پنجره</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>تغییر به حالت تمام صفحه</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>تغییر به حالت پنجره</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>تغییر به حالت تمام صفحه</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>دوربین</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>تنظیمات موفقیت آمیز بود</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>بستن پنجره و شروع دوباره برنامه</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>از وکواسکرین لذت ببرید</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>گفتگو</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>انتخاب یک یا چند دستگاه </translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>راهنما</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>برنامه مدیریت فایل پیدا نشد.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>لطفا برنامه یک برنامه مدیریت فایل نصب کنید.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>هشدار</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>ضبط شروع نشد,
چون فضای کافی وجود ندارد.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>فضای خالی به محدودیت اش رسیده است.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>محدودیت فضای خالی حافظه</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>مگابایت</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>ضبط متوقف شده است,
چون فضای کافی وجود ندارد.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>برنامه مدیریت فایل پیدا نشد.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>لطفا برنامه یک برنامه مدیریت فایل نصب کنید.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>کد منبع</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>صفحه اصلی</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>ترجمه ها</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>حمایت</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>کد منبع</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>صفحه اصلی</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>ترجمه ها</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>حمایت</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>انتخاب یک یا چند دستگاه </translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>محیط</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>محیط</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>برنامه مدیریت فایل پیدا نشد.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>لطفا برنامه یک برنامه مدیریت فایل نصب کنید.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>شروع</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>پایان</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>وقفه</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>ادامه</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>دوربین</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>بزرگنمایی</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>شروع</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>توقف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>وقفه</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>ادامه</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>دوربین</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>بزرگنمایی</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>انتخاب یک یا چند دستگاه </translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>گفتگو</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>افقی چرخاندن</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>عمودی چرخاندن</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>معکوس کردن</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>خاکستری</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>سیاه و سفید</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>حذف فریم دور پنچره</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>تنظیمات دوربین</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>محیط</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>بازنشانی</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>بزرگنمایی</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>شمارنده</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>اندازه ویدیو:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>فضای آزاد حافظه:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>اطلاعات</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>زمان ضبط:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>صدا</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>فریم‌ها</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>کدک ویدیو</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>فرمت</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>کدک صدا</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>نشانگر موس را ضبط نکن</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>ساعت</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>دقیقه</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>شروع تامیر</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>پایان ضبط بعدی از</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>ساعت</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>دقیقه</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>ثانیه</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>مسیر ویدیو</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>محدودیت فضای خالی حافظه</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>نمایش در systray</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>ثانیه صبر کن قبل از شروع ضبط</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>بررسی برای بروزرسانی</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>راهنما</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ویدیو</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>دردسترس است</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>دردسترس نیست</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>شروع</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>توقف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>وقفه</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>ادامه</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>پخش</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>پوشه</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>دوربین</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>معکوس کردن</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>سیاه و سفید</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>پخش آخرین ویدیو ضبط شده</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>باز کرده پوشه</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>کوچک سازی هنگام شروع ضبط</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>شروع به صورت کوچک شده</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>افقی چرخاندن</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>عمودی چرخاندن</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>سیاه و سفید</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>حذف فریم دور پنچره</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>بازنشانی همه تنظیمات در شروع بعدی</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>کپی رایت و مجوز برای عکس ها</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>مگابایت</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>پخش فیلم</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>پخش کننده</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>لاگ</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>خودکار</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>ایجاد تصاویر برای هر تب</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>اطلاعات لایسنس</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>روشن</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>خاموش</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>میانبرهای فراگیر صفحه کلید</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>کلیدهای میانبر تعریف شده </translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>میانبر صفحه کلید تعریف نشده یا بیش از یکبار تعریف شده</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>اگر تعریف شده نشان داده شده اما کار نمیکند،توسط برنامه دیگری استفاده شده</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>عکس گرفتن فوری</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>مسیر تصویر</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>مخفی سازی پنجره</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>تعداد ثانیه‌هایی که باید قبل از شروع ضبط منتظر بمانید </translation>
    </message>
    <message>
        <source>Window</source>
        <translation>پنجره</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>تمام صفحه</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>کپی رایت و مجوز برای عکس ها</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>ایجاد تصاویر برای هر تب</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>اطلاعات لایسنس</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>روشن</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>خاموش</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>زمان ضبط:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>اندازه ویدیو:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>فضای آزاد حافظه:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>اطلاعات</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>پنجره</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>تمام صفحه</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>محیط</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>کدک ویدیو</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>فریم‌ها</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>فرمت</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>دردسترس است</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>دردسترس نیست</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>شروع</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>پایان</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>وقفه</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>ادامه</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>پخش</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>پوشه</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>نشانگر موس را ضبط نکن</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>کپی رایت و مجوز برای عکس ها</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>پخش</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>وقفه</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>پایان</translation>
    </message>
</context>
</TS>